# genre.py


```
Usage: genre.py [OPTIONS] [FILES]...

Options:
  -q, --query TEXT    Specify a query to use when searching for a matching
                      track.
  -y, --yes-if-exact  Do not wait for user confirmtion if match is exact
  -d, --dry-run       Perform lookup but do not write tags.
  --help              Show this message and exit.
```